@@ -9,7 +9,7 @@ import requests
 import six
 from six.moves.urllib import parse
 
-from .core import Experiment, Subject, State, Workflow
+from .core import Experiment, Subject, State, Workflow, Action, Transition
 from .drivers import DRIVERS
 from .exceptions import StudyGovernorValueError
 from .exceptions import StudyGovernorNoAuthError
@@ -24,6 +24,8 @@ class StudyClient(object):
         Subject: '__subjects__',
         State: '__states__',
         Workflow: '__workflows__',
+        Action: '__actions__',
+        Transition: '__transitions__',
     }
 
     def __init__(self, server, user=None, password=None, session=None, logger=None,
@@ -60,11 +62,13 @@ class StudyClient(object):
             )
 
             # Add user agent prefix if needed
-            if user_agent_prefix:
-                user_agent = "{user_agent_prefix} {user_agent}".format(
-                    user_agent_prefix=user_agent_prefix,
-                    user_agent=user_agent
-                )
+            if not user_agent_prefix:
+                user_agent_prefix = 'studygovernor-client'
+
+            user_agent = "{user_agent_prefix} {user_agent}".format(
+                user_agent_prefix=user_agent_prefix,
+                user_agent=user_agent
+            )
 
         # Set user agent and accept content type headers
         self.interface.headers.update({
